@@ -23,10 +23,10 @@ class abstractclassmethod(classmethod):
 
     def __init__(self, target):
         target.__isabstractmethod__ = True
-        super(abstractclassmethod, self).__init__(target)
+        super().__init__(target)
 
 
-class ComparableX509(object):  # pylint: disable=too-few-public-methods
+class ComparableX509:  # pylint: disable=too-few-public-methods
     """Wrapper for OpenSSL.crypto.X509** objects that supports __eq__.
 
     :ivar wrapped: Wrapped certificate or certificate request.
@@ -69,14 +69,11 @@ class ComparableX509(object):  # pylint: disable=too-few-public-methods
     def __hash__(self):
         return hash((self.__class__, self._dump()))
 
-    def __ne__(self, other):
-        return not self == other
-
     def __repr__(self):
         return '<{0}({1!r})>'.format(self.__class__.__name__, self.wrapped)
 
 
-class ComparableKey(object):  # pylint: disable=too-few-public-methods
+class ComparableKey:  # pylint: disable=too-few-public-methods
     """Comparable wrapper for ``cryptography`` keys.
 
     See https://github.com/pyca/cryptography/issues/2122.
@@ -102,9 +99,6 @@ class ComparableKey(object):  # pylint: disable=too-few-public-methods
         else:
             return NotImplemented
 
-    def __ne__(self, other):
-        return not self == other
-
     def __repr__(self):
         return '<{0}({1!r})>'.format(self.__class__.__name__, self._wrapped)
 
@@ -164,7 +158,7 @@ class ComparableECKey(ComparableKey):  # pylint: disable=too-few-public-methods
         return self.__class__(key)
 
 
-class ImmutableMap(Mapping, Hashable):  # type: ignore
+class ImmutableMap(Mapping, Hashable):
     # pylint: disable=too-few-public-methods
     """Immutable key to value mapping with attribute access."""
 
@@ -182,8 +176,7 @@ class ImmutableMap(Mapping, Hashable):  # type: ignore
 
     def update(self, **kwargs):
         """Return updated map."""
-        items = dict(self)
-        items.update(kwargs)
+        items = {**self, **kwargs}
         return type(self)(**items)  # pylint: disable=star-args
 
     def __getitem__(self, key):
@@ -210,7 +203,7 @@ class ImmutableMap(Mapping, Hashable):  # type: ignore
             for key, value in self.items()))
 
 
-class frozendict(Mapping, Hashable):  # type: ignore
+class frozendict(Mapping, Hashable):
     # pylint: disable=invalid-name,too-few-public-methods
     """Frozen dictionary."""
     __slots__ = ('_items', '_keys')
